@@ -20,7 +20,7 @@ from Cryptodome.Cipher import AES
 from Cryptodome.Protocol.KDF import PBKDF2
 from pydantic.dataclasses import dataclass
 
-from bigeye_aws.functions.aws import get_secret
+from bigeye_sdk.functions.aws import get_secret
 from bigeye_sdk.authentication.enums import BrowserType, OperatingSystem
 from bigeye_sdk.exceptions import BrowserAuthException
 from bigeye_sdk.log import get_logger
