@@ -601,7 +601,7 @@ class DatawatchClient(BaseApiClient, GeneratedDatawatchClient, ABC):
         :return: Id of the resulting metric.
         """
         # TODO Consider moving warehouse_id into sumr
-        if sumr.metric_template.metric_name is None:
+        if sumr.metric_name is None:
             raise Exception("Metric name must be present in configuration", sumr)
 
         tables = self.get_tables(warehouse_id=[sumr.warehouse_id], schema=[sumr.schema_name],
@@ -623,15 +623,15 @@ class DatawatchClient(BaseApiClient, GeneratedDatawatchClient, ABC):
                 warehouse_id=sumr.warehouse_id,
                 table=table,
                 column_name=sumr.column_name,
-                user_defined_name=sumr.metric_template.user_defined_metric_name,
-                metric_name=sumr.metric_template.metric_name,
-                group_by=sumr.metric_template.group_by,
-                filters=sumr.metric_template.filters)
+                user_defined_name=sumr.user_defined_metric_name,
+                metric_name=sumr.metric_name,
+                group_by=sumr.group_by,
+                filters=sumr.filters)
 
         metric = sumr.to_datawatch_object(target_table=table, existing_metric=existing_metric)
 
         should_backfill = False
-        if metric.id is None and not is_freshness_metric(sumr.metric_template.metric_name):
+        if metric.id is None and not is_freshness_metric(sumr.metric_name):
             should_backfill = True
 
         result = self.upsert_metric(metric_configuration=metric)
