@@ -296,7 +296,7 @@ def set_default_model_type_for_threshold(thresholds: List[Threshold]) -> List[Th
 
 
 def get_thresholds_for_metric(metric_name: str, timezone: str = None, delay_at_update: str = None,
-                              update_schedule: str = None, thresholds: List[Threshold] = None) -> List[Threshold]:
+                              update_schedule: str = None, thresholds: List[dict] = None) -> List[Threshold]:
     """
     Gets a list of appropriate Thresholds for a metric.
 
@@ -309,7 +309,7 @@ def get_thresholds_for_metric(metric_name: str, timezone: str = None, delay_at_u
     :returns: List[Threshold]
     """
     if thresholds:
-        return thresholds
+        return [Threshold().from_dict(t) for t in thresholds]
     # If it's a freshness
     elif is_freshness_metric(metric_name):
         tj = {
