@@ -3,7 +3,7 @@ from __future__ import annotations
 import inspect
 import uuid
 from dataclasses import field
-from typing import List
+from typing import List, Union
 
 from pydantic.dataclasses import dataclass
 
@@ -20,7 +20,7 @@ from bigeye_sdk.serializable import YamlSerializable
 
 
 @dataclass
-class SimplePredefinedMetricTemplate(YamlSerializable, DatawatchFacade):
+class SimplePredefinedMetricTemplate(YamlSerializable):
     """
     Provides a simple, reusable, string based metric template for versioning and upserting metrics.  Includes
     methods to convert to and from protobuf CreateMetricRequest objects and fills in reasonable defaults.
@@ -62,9 +62,9 @@ class SimplePredefinedMetricTemplate(YamlSerializable, DatawatchFacade):
                 - that_other_column
             widnow_size: '1 hour'
     """
-    metric_name: str
+    metric_name: str = ""
     notifications: List[str] = field(default_factory=lambda: [])
-    thresholds: List[Threshold] = field(default_factory=lambda: [])
+    thresholds: List[dict] = field(default_factory=lambda: [])
     filters: List[str] = field(default_factory=lambda: [])
     group_by: List[str] = field(default_factory=lambda: [])
     user_defined_metric_name: str = None
@@ -85,7 +85,7 @@ class SimplePredefinedMetricTemplate(YamlSerializable, DatawatchFacade):
             self.user_defined_metric_name = self.metric_name
 
     @classmethod
-    def from_datawatch_object(cls, mc: MetricConfiguration) -> SimplePredefinedMetricTemplate:
+    def _from_datawatch_object(cls, mc: MetricConfiguration) -> SimplePredefinedMetricTemplate:
         builder = SimplePredefinedMetricTemplate(metric_name=SimpleMetricCategory.get_metric_name(mc.metric_type))
         builder.user_defined_metric_name = mc.name
         builder.metric_type = SimpleMetricCategory.get_simple_metric_category(mc.metric_type)
@@ -99,10 +99,10 @@ class SimplePredefinedMetricTemplate(YamlSerializable, DatawatchFacade):
 
         return builder
 
-    def to_datawatch_object(self,
-                            target_table: Table,
-                            column_name: str,
-                            existing_metric: MetricConfiguration = None) -> MetricConfiguration:
+    def _to_datawatch_object(self,
+                             target_table: Table,
+                             column_name: str,
+                             existing_metric: MetricConfiguration = None) -> MetricConfiguration:
         """
         Converts a SimplePredefinedMetricTemplate to a MetricConfiguration that can be used to upsert a metric to Bigeye API.
         Must include either a column name or an existing metric
@@ -178,23 +178,16 @@ class SimplePredefinedMetricTemplate(YamlSerializable, DatawatchFacade):
 
 
 @dataclass
-class SimpleMetricConfiguration(YamlSerializable):
+class SimpleMetricConfiguration(SimplePredefinedMetricTemplate):
     """
     Versionable Metric Configuration.  Wraps SimplePredefinedMetricTemplate to include warehouse_id, schema_name, table_name and
     column_name.
     """
-    warehouse_id: int
-    schema_name: str
-    table_name: str
-    column_name: str
-    metric_template: SimplePredefinedMetricTemplate = None
+    warehouse_id: int = None
+    schema_name: str = None
+    table_name: str = None
+    column_name: str = None
     metric_template_id: uuid.UUID = None
-    # Could make SimpleMetricConfiguration a child of SimpleMetrictemplate and remove hierarchy but keeping the
-    # template as an attribute creates the opportuninty to add a metric_template hash instead.  Still pondering.
-
-    def __post_init__(self):
-        if not self.metric_template and not self.metric_template_id:
-            raise InvalidConfigurationException('Must include either a metric template id OR a metric template.')
 
 
 @dataclass
@@ -207,21 +200,6 @@ class SimpleUpsertMetricRequest(SimpleMetricConfiguration):
 
     def to_datawatch_object(self, target_table: Table,
                             existing_metric: MetricConfiguration = None) -> MetricConfiguration:
-        return self.metric_template.to_datawatch_object(target_table=target_table,
-                                                        column_name=self.column_name,
-                                                        existing_metric=existing_metric)
-
-    @classmethod
-    def from_dict(cls, d: dict) -> SimpleUpsertMetricRequest:
-        """
-        Processes a dict conf containing all attributes at the top level to a SUMR
-        :param d: configuration dictionary.
-        :return: SimpleUpsertMetricRequest
-        """
-        [cls_params, smt_params] = map(lambda keys: {x: d[x] for x in keys if x in d},
-                                       [inspect.signature(cls).parameters,
-                                        inspect.signature(SimplePredefinedMetricTemplate).parameters])
-
-        cls_params["metric_template"] = SimplePredefinedMetricTemplate(**smt_params) if smt_params \
-            else SimplePredefinedMetricTemplate(**cls_params["metric_template"])
-        return cls(**cls_params)
+        return self._to_datawatch_object(target_table=target_table,
+                                         column_name=self.column_name,
+                                         existing_metric=existing_metric)
